GNN Layer Implementation for HNSW Topology
This module implements graph neural network layers that operate on HNSW graph structure, including attention mechanisms, normalization, and gated recurrent updates.
Structs
- GRUCell
- Gated Recurrent Unit (GRU) cell for state updates
- Layer
Norm - Layer normalization
- Linear
- Linear transformation layer (weight matrix multiplication)
- Multi
Head Attention - Multi-head attention mechanism
- Ruvector
Layer - Main GNN layer operating on HNSW topology