Module layer

Module layer 

GNN Layer Implementation for HNSW Topology

This module implements graph neural network layers that operate on HNSW graph structure, including attention mechanisms, normalization, and gated recurrent updates.

Structs

GRUCell
Gated Recurrent Unit (GRU) cell for state updates
LayerNorm
Layer normalization
Linear
Linear transformation layer (weight matrix multiplication)
MultiHeadAttention
Multi-head attention mechanism
RuvectorLayer
Main GNN layer operating on HNSW topology